.. _datasets:

=========================
Dataset loading utilities
=========================
.. module:: grakel.datasets

A module for loading and fetching datasets related with graph kernels.

.. autosummary::
   :toctree: generated/
   
   grakel.datasets.fetch_dataset
   grakel.datasets.get_dataset_info

.. _gd:	https://ls11-www.cs.tu-dortmund.de/staff/morris/graphkerneldatasets